==> dolfin-0.3.10.tar.gz: dolfin-0.3.10/src/kernel/main/Problem.cpp <==
// Copyright (C) 2003 Johan Hoffman and Anders Logg.
// Licensed under the GNU GPL Version 2.

#include <stdarg.h>

#include "dolfin_modules.h"
#include <dolfin/Problem.h>

using namespace dolfin;

//-----------------------------------------------------------------------------
Problem::Problem(const char* problem)
{
  // Initialise the solver
  solver = dolfin_module_solver(problem);
}
//-----------------------------------------------------------------------------
Problem::Problem(const char* problem, Grid& grid)
{
  // Initialise the solver
  solver = dolfin_module_solver(problem, grid);
}
//-----------------------------------------------------------------------------
Problem::Problem(const char* problem, ODE& ode)
{
  // Initialise the solver
  solver = dolfin_module_solver(problem, ode);
}
//-----------------------------------------------------------------------------
Problem::~Problem()
{
  if ( solver )
    delete solver;
  solver = 0;
}
//-----------------------------------------------------------------------------
void Problem::set(const char *property, ...)
{
  va_list aptr;
  va_start(aptr, property);
  
  // Settings are global, although the syntax problem.set() seems to indicate
  // that parameters are local to a given problem.
  dolfin_set_aptr(property, aptr);
  
  va_end(aptr);
}
//-----------------------------------------------------------------------------
void Problem::solve()
{
  solver->solve();
}
//-----------------------------------------------------------------------------

==> dolfin-0.4.1.tar.gz: dolfin-0.4.1/src/kernel/main/Problem.cpp <==
// Copyright (C) 2003 Johan Hoffman and Anders Logg.
// Licensed under the GNU GPL Version 2.

#include <stdarg.h>

#include "dolfin_modules.h"
#include <dolfin/Problem.h>

using namespace dolfin;

//-----------------------------------------------------------------------------
Problem::Problem(const char* problem)
{
  // Initialise the solver
  solver = dolfin_module_solver(problem);
}
//-----------------------------------------------------------------------------
Problem::Problem(const char* problem, Mesh& mesh)
{
  // Initialise the solver
  solver = dolfin_module_solver(problem, mesh);
}
//-----------------------------------------------------------------------------
Problem::Problem(const char* problem, ODE& ode)
{
  // Initialise the solver
  solver = dolfin_module_solver(problem, ode);
}
//-----------------------------------------------------------------------------
Problem::~Problem()
{
  if ( solver )
    delete solver;
  solver = 0;
}
//-----------------------------------------------------------------------------
void Problem::set(const char *property, ...)
{
  va_list aptr;
  va_start(aptr, property);
  
  // Settings are global, although the syntax problem.set() seems to indicate
  // that parameters are local to a given problem.
  dolfin_set_aptr(property, aptr);
  
  va_end(aptr);
}
//-----------------------------------------------------------------------------
void Problem::solve()
{
  solver->solve();
}
//-----------------------------------------------------------------------------
